import unittest

import sys
sys.path.append('..')

import rlfl
from tmap import MAP as m
MAP, ORIGOS = m

class TestLos(unittest.TestCase):
    def setUp(self):
        self.map = rlfl.create_map(len(MAP), len(MAP[0]))
        for row in range(len(MAP)):
            for col in range(len(MAP[row])):
                if MAP[row][col] != '#':
                    rlfl.set_flag(self.map, row, col, rlfl.CELL_SEEN) 
                    rlfl.set_flag(self.map, row, col, rlfl.CELL_OPEN) 
    
    def test_los(self):
        x, y = ORIGOS[0]
        x1, y1 = ORIGOS[1]
        x2, y2 = ORIGOS[2]
        x3, y3 = ORIGOS[3]
        self.assertFalse(rlfl.los(self.map, x1, y1, x3, y3))
        self.assertFalse(rlfl.los(self.map, x3, y3, x1, y1))
        self.assertTrue(rlfl.los(self.map, x, y, x3, y3))
        self.assertTrue(rlfl.los(self.map, x3, y3, x, y))

if __name__ == '__main__':
    unittest.main()


import unittest

import sys
sys.path.append('..')

import rlfl
from tmap import MAP as m
MAP, ORIGOS = m

class TestPath(unittest.TestCase):  
    def setUp(self):
        self.map = rlfl.create_map(len(MAP), len(MAP[0]))
        for row in range(len(MAP)):
            for col in range(len(MAP[row])):
                if MAP[row][col] != '#':
                    rlfl.set_flag(self.map, row, col, rlfl.CELL_SEEN) 
                    rlfl.set_flag(self.map, row, col, rlfl.CELL_OPEN) 
    
    def test_create(self):
        p = ORIGOS[0]
        p1 = ORIGOS[1]
        p2 = ORIGOS[2]
        p3 = ORIGOS[3]
        self.assertEqual(False, rlfl.path(self.map, (0,0), (1000,1000)), ORIGOS[2])
        self.assertEqual(False, rlfl.path(self.map, p, p1), ORIGOS[1])
        self.assertEqual(False, rlfl.path(self.map, p2, p3), ORIGOS[3])
        self.assertEqual(False, rlfl.path(self.map, p2, p), ORIGOS[0])
        r = ((18, 33), (17, 33), (16, 33), (15, 33), (14, 33), (13, 33), (12, 32), (11, 32), (10, 32), (9, 32))
        self.assertEqual(r, rlfl.path(self.map, p, p3), ORIGOS[3])
        r = ((15, 11), (15, 10), (15, 9), (15, 8), (15, 7), (15, 6))
        self.assertEqual(r, rlfl.path(self.map, p1, p2), ORIGOS[2])
    
    def print_path(self, path, t):
        if not path:
            print("NO PATH")
            return
        for row in range(len(MAP)):
            for col in range(len(MAP[row])):
                if (row, col) == t:
                    print('T', end="")
                elif (row, col) in path:
                    print('*', end="")
#                elif (row, col) == (9, 32):
#                    print('X', end="")
                else:
                    print(MAP[row][col], end="")
            print() 
        print()

if __name__ == '__main__':
    unittest.main()


import unittest

import sys
sys.path.append('..')

import rlfl
from tmap import MAP as m
MAP, ORIGOS = m

class TestMap(unittest.TestCase):   
    def test_create(self):
        rlfl.delete_all_maps()
        for m in range(rlfl.MAX_MAPS):
            self.assertEqual(m, rlfl.create_map(20, 20))
        self.assertFalse(rlfl.create_map(20, 20))
        
    def test_delete(self):
        rlfl.delete_all_maps()
        for m in range(rlfl.MAX_MAPS):
            rlfl.create_map(20, 20)
        self.assertFalse(rlfl.create_map(20, 20))
        rlfl.delete_all_maps()
        self.assertEqual(0, rlfl.create_map(20, 20))
        self.assertTrue(rlfl.delete_map(0))
        self.assertEqual(0, rlfl.create_map(20, 20))
        
    def test_flags(self):
        rlfl.delete_all_maps()
        rlfl.create_map(20, 20)
        self.assertFalse(rlfl.has_flag(0, 10, 10, rlfl.CELL_OPEN))
        rlfl.set_flag(0, 10, 10, rlfl.CELL_OPEN)
        self.assertTrue(rlfl.has_flag(0, 10, 10, rlfl.CELL_OPEN))
        self.assertEqual(rlfl.CELL_OPEN, rlfl.get_flags(0, 10, 10))
        rlfl.set_flag(0, 10, 10, rlfl.CELL_SEEN)
        self.assertEqual(rlfl.CELL_OPEN | rlfl.CELL_SEEN, rlfl.get_flags(0, 10, 10))
        rlfl.clear_flag(0, 10, 10, rlfl.CELL_OPEN)
        self.assertFalse(rlfl.has_flag(0, 10, 10, rlfl.CELL_OPEN))
        self.assertTrue(rlfl.has_flag(0, 10, 10, rlfl.CELL_SEEN))
        rlfl.clear_flag(0, 10, 10, rlfl.CELL_SEEN)
        rlfl.set_flag(0, 10, 10, rlfl.CELL_MASK)
        self.assertTrue(rlfl.has_flag(0, 10, 10, rlfl.CELL_OPEN))
        
    def test_map(self):
        rlfl.delete_all_maps()
        rlfl.create_map(20, 20)
        rlfl.fill_map(0, rlfl.CELL_SEEN)
        for i in range(20):
            for j in range(20):
                self.assertTrue(rlfl.has_flag(0, i, j, rlfl.CELL_SEEN))
#        rlfl.clear_map(6)
        rlfl.clear_map(0)
        for i in range(20):
            for j in range(20):
                self.assertFalse(rlfl.has_flag(0, i, j, rlfl.CELL_SEEN))

if __name__ == '__main__':
    unittest.main()


import unittest

import sys
sys.path.append('..')
import rlfl
from tmap import MAP as m
MAP, ORIGOS = m

class TestDistance(unittest.TestCase):   
    def setUp(self):
        self.map = rlfl.create_map(len(MAP), len(MAP[0]))
        for row in range(len(MAP)):
            for col in range(len(MAP[row])):
                if MAP[row][col] != '#':
                    rlfl.set_flag(self.map, row, col, rlfl.CELL_SEEN) 
                    rlfl.set_flag(self.map, row, col, rlfl.CELL_OPEN) 
    
    def test_scatter(self):
        x, y = ORIGOS[0]
        for i in range(10):
            px, py = rlfl.scatter(self.map, x, y, 10, rlfl.CELL_OPEN)
            self.assertTrue(px < (x + 10))
            self.assertTrue(px >= (x - 10))
            self.assertTrue(py < (y + 10))
            self.assertTrue(py >= (y - 10))
            self.assertTrue(rlfl.has_flag(self.map, px, py, rlfl.CELL_OPEN))
        
if __name__ == '__main__':
    unittest.main()


# -*- coding: utf-8 -*-
from distutils.core import setup
from distutils.extension import Extension

rlfl = Extension('rlfl',
                 define_macros = [('DEBUG', '0')],
                 sources = [
                    'src/random.c',
                    'src/list_t.c',
                    'src/rlf.c',
                    'src/los.c',
                    'src/path_astar2.c',
                    'src/project.c',
                    'src/fov_circular_raycasting.c',
                    'src/fov_recursive_shadowcasting.c',
                    'src/fov_diamond_raycasting.c',
                    'src/fov_permissive.c',
                    'src/fov_restrictive.c',
                    'src/fov_digital.c',
                    'src/project.c',
                    'src/rlftopy.c'
                ]
)
setup(
    name='rlfl',
    version='1.0',
    author='Jóhann T. Maríusson',
    author_email='jtm@robot.is',
    keywords = ["game", "roguelike"],
    url='http://pypi.python.org/pypi/RLFL/',
    license='LICENSE.txt',
    description='Roguelike Function Library.',
    long_description=open('README').read(),
    ext_modules=[rlfl],
)


import unittest

import sys
sys.path.append('..')
import rlfl

class TestDistance(unittest.TestCase):   
    def test_distance(self):
        x, y, x1, y1 = (1, 1, 1, 1)
        self.assertEqual(rlfl.distance(x, y, x1, y1), 0)
        x, y, x1, y1 = (1, 1, 2, 2)
        self.assertEqual(rlfl.distance(x, y, x1, y1), 1)
        x, y, x1, y1 = (1, 1, 11, 11)
        self.assertEqual(rlfl.distance(x, y, x1, y1), 15)
        x, y, x1, y1 = (1, 1, 0, 0)
        self.assertEqual(rlfl.distance(x, y, x1, y1), 1)

if __name__ == '__main__':
    unittest.main()